SystemOrganization addCategory: #'DAO-SatelliteTests'!

TestCase subclass: #CommandParameterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!CommandParameterTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 14:14'!
testDeserializeNegativeSigned16BitInteger
	| serializedValue parameter streamDeLectura |
	
	serializedValue := #[1 1].
	streamDeLectura := ReadStream on: serializedValue.
	parameter := SignedIntegerCommandParameter newWithName: 'temp' andBitSize: 16.
	
	self assert: parameter name equals: 'temp'.
	self assert: (parameter deserialize: streamDeLectura) equals: -1.! !

!CommandParameterTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 14:15'!
testDeserializePositiveSigned16BitInteger
| serializedValue parameter streamDeLectura |
	
	serializedValue := #[0 1].
	streamDeLectura := ReadStream on: serializedValue.
	parameter := SignedIntegerCommandParameter newWithName: 'temp' andBitSize: 16.
	
	self assert: parameter name equals: 'temp'.
	self assert: (parameter deserialize: streamDeLectura) equals: 1.! !

!CommandParameterTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 16:11'!
testSerializeNegativeSigned32BitInteger
	| parameter |
	
	parameter := SignedIntegerCommandParameter newWithName: 'temp' andBitSize: 32.
	parameter value: -1.
	
	self assert: (parameter serialize) equals: #[1 0 0 1].
! !

!CommandParameterTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 16:11'!
testSerializePositiveSigned32BitInteger
	| parameter |
	
	parameter := SignedIntegerCommandParameter newWithName: 'temp' andBitSize: 32.
	parameter value: 1.
	
	self assert: (parameter serialize) equals: #[0 0 0 1].
! !

!CommandParameterTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 14:16'!
testSerializeString8
	| parameter |
	
	parameter := StringCommandParameter newWithName: 'temp' andBitSize: 8.
	parameter value: 'Hello'.
	
	self assert: (parameter serialize) equals: #[5 72 101 108 108 111].! !

!CommandParameterTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 14:16'!
testSerializeUnsigned32BitInteger
	| parameter |
	
	parameter := UnsignedIntegerCommandParameter newWithName: 'temp' andBitSize: 32.
	parameter value: 1.
	
	self assert: (parameter serialize) equals: #[0 0 0 1].! !

TestCase subclass: #CommandRequestTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 12:19'!
testSerializingCommandWithFiveU32ParametersShouldSerializeOK
	
	| command commandDefinition |
	
	commandDefinition := CommandDefinition memoryReadChunkedAddress.

	command := CommandRequest for: commandDefinition.

	command addParameterValue: 1.
	command addParameterValue: 2.
	command addParameterValue: 3.
	command addParameterValue: 4.
	command addParameterValue: 5.
	
	self assert: command serialize equals: #[45 0 0 0 1 0 0 0 2 0 0 0 3 0 0 0 4 0 0 0 5]! !

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 12:20'!
testSerializingCommandWithMaxValueSetToOneU24ParameterShouldSerializeOK
	
	| commandDefinition command |
	
	commandDefinition := CommandDefinition powerStbSetSwitchesState.

	command := CommandRequest for: commandDefinition.

	command addParameterValue: 16777215.
	
	self assert: command serialize equals: #[36 255 255 255]! !

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 12:21'!
testSerializingCommandWithMaxValueSetToOneU8ParameterShouldSerializeOK
	
	| command commandDefinition |
	
	commandDefinition := CommandDefinition platformSetMode.
	
	command := CommandRequest for: commandDefinition.

	command addParameterValue: 255.
	
	self assert: command serialize equals: #[32 255]! !

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 12:22'!
testSerializingCommandWithMaxValuesSetToTwoU32ParametersShouldSerializeOK
	
	| command commandDefinition |
	
	commandDefinition := CommandDefinition memoryReadLongAddress.

	command := CommandRequest for: commandDefinition.

	command addParameterValue: 4294967295.
	command addParameterValue: 4294967295.
	
	self assert: command serialize equals: #[44 255 255 255 255 255 255 255 255]! !

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 12:22'!
testSerializingCommandWithOneU24ParameterShouldSerializeOK
	
	| command commandDefinition |
	
	commandDefinition := CommandDefinition powerStbSetSwitchesState.

	command := CommandRequest for: commandDefinition.

	command addParameterValue: 1.
	
	self assert: command serialize equals: #[36 0 0 1]! !

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 12:22'!
testSerializingCommandWithOneU32AndOneString8ParametersShouldSerializeOK
	
	| command commandDefinition |
	
	commandDefinition := CommandDefinition memoryWriteAddress.

	command := CommandRequest for: commandDefinition.

	command addParameterValue: 1.
	command addParameterValue: 'Hello'.
	
	self assert: command serialize = #[33 0 0 0 1 5 72 101 108 108 111]! !

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 12:23'!
testSerializingCommandWithOneU32ParameterShouldSerializeOK
	
	| command commandDefinition |
	
	commandDefinition := CommandDefinition thermalSetMatrixKey.

	command := CommandRequest for: commandDefinition.

	command addParameterValue: 1.
	
	self assert: command serialize equals: #[32 0 0 0 1]! !

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 12:23'!
testSerializingCommandWithTwoU32ParametersShouldSerializeOK
	
	| command commandDefinition |
	
	commandDefinition :=CommandDefinition memoryReadLongAddress.

	command := CommandRequest for: commandDefinition.

	command addParameterValue: 1.
	command addParameterValue: 2.
	
	self assert: command serialize equals: #[44 0 0 0 1 0 0 0 2]! !

!CommandRequestTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 12:24'!
testSerializingCommandWithoutParametersShouldSerializeCommandIdOnly
	
	| command commandDefinition |
	
	commandDefinition := CommandDefinition thermalTelemetry.

	command := CommandRequest for: commandDefinition.

	self assert: command serialize equals: #[1]! !

TestCase subclass: #CommandResponseTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!CommandResponseTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 13:53'!
testDeserializingArrayOfUnsigned8BitIntegerShouldReturnTheDecodedArray

	| encodedResponse decodedResponse commandDefinition array |
	
	"setup"
	"001 sequence number, 1 first byte, 2 second"
	encodedResponse := #[0 0 1 1 2].

	commandDefinition := CommandDefinition memoryReadAddress.
	
	"exercise"	
	decodedResponse := CommandResponse from: encodedResponse using: commandDefinition responseDefinition.
	
	"verify"
	self assert: decodedResponse sequenceNumber equals: 1.
	self assert: (decodedResponse data size) equals: 1.
	
	array := (decodedResponse data at: 1).
	
	self assert: array size equals: 2.
	self assert: (array at: 1) equals: 1.
	self assert: (array at: 2) equals: 2.

! !

!CommandResponseTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 13:53'!
testDeserializingThermalNameResponseShouldReturnThermal

	| encodedResponse decodedResponse commandDefinition |

	"001 sequence number, lo que le sigue THERMAL codificado"
	encodedResponse := #[0 0 1 84 72 69 82 77 65 76].
	
	commandDefinition := CommandDefinition getNameCommand.
	
	decodedResponse := CommandResponse from: encodedResponse using: commandDefinition responseDefinition.
	
	self assert: decodedResponse sequenceNumber equals: 1.
	self assert: (decodedResponse data size) equals: 1.
	self assert: (decodedResponse data at: 1) equals: 'THERMAL'.! !

!CommandResponseTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 13:53'!
testDeserializingThermalSetMatrixKeyResponseShouldReturnVoid

	| encodedResponse commandDefinition decodedResponse |
	
	"001 sequence number, then empty response"
	encodedResponse := #[0 0 1].
	
	commandDefinition :=  CommandDefinition thermalSetMatrixKey.
	
	decodedResponse := CommandResponse from: encodedResponse using: commandDefinition responseDefinition.
	
	self assert: decodedResponse sequenceNumber equals: 1.
	self assert: (decodedResponse class) equals: VoidCommandResponse.
	
! !

!CommandResponseTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 13:56'!
testDeserializingThermalShortTelemetryResponseShouldReturnThermalShortTelemetry

	| encodedResponse commandDefinition decodedResponse |
	
	"001 sequence number, 1 battery temp"
	encodedResponse := #[0 0 1 1].

	commandDefinition :=  CommandDefinition thermalShortTelemetry.
	
	decodedResponse := CommandResponse from: encodedResponse using: commandDefinition responseDefinition.

	self assert: decodedResponse sequenceNumber equals: 1.
	self assert: (decodedResponse data at: 1) equals: 1.
	
! !

!CommandResponseTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 13:57'!
testDeserializingThermalTelemetryResponseContainingNegativeNumbersShouldDeserializeOK

	| encodedResponse decodedResponse commandDefinition |
	
	"001 sequence number, 1 1 battery temp, 1 2 radio temp"
	encodedResponse := #[0 0 1 1 1 1 2].

	commandDefinition := CommandDefinition thermalTelemetry.
		
	decodedResponse := CommandResponse from: encodedResponse using: commandDefinition responseDefinition.

	self assert: decodedResponse sequenceNumber equals: 1.
	self assert: (decodedResponse data at: 1) equals: -1.
	self assert: (decodedResponse data at: 2) equals: -2.
! !

!CommandResponseTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 13:57'!
testDeserializingThermalTelemetryResponseShouldReturnThermalTelemetry

	| encodedResponse decodedResponse commandDefinition |
	
	"001 sequence number, 0 1 battery temp, 0 2 radio temp"
	encodedResponse := #[0 0 1 0 1 0 2].

	commandDefinition := CommandDefinition thermalTelemetry.
		
	decodedResponse := CommandResponse from: encodedResponse using: commandDefinition responseDefinition.

	self assert: decodedResponse sequenceNumber equals: 1.
	self assert: (decodedResponse data at: 1) equals: 1.
	self assert: (decodedResponse data at: 2) equals: 2.
! !

!CommandResponseTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 13:57'!
testDeserializingUsigned32BitIntegerAndArrayOfUnsigned8BitIntegerShouldDeserializeOK

	| encodedResponse decodedResponse commandDefinition array firstElement |
	
	"setup"
	"001 sequence number, 0 0 0 1 first element of the response,  then 1 and 2 are the elements of the array"
	encodedResponse := #[0 0 1 0 0 0 1 1 2].

	commandDefinition := CommandDefinition memoryReadLongAddress.
	
	"exercise"	
	decodedResponse := CommandResponse from: encodedResponse using: commandDefinition responseDefinition.
	
	"verify"
	self assert: decodedResponse sequenceNumber equals: 1.

	self assert: (decodedResponse data size) equals: 2.
	
	firstElement := decodedResponse data at: 1.
	self assert: firstElement equals: 1.
	
	array := (decodedResponse data at: 2).
	self assert: array size equals: 2.
	self assert: (array at: 1) equals: 1.
	self assert: (array at: 2) equals: 2.

! !

TestCase subclass: #CommandTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!CommandTest class methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:06'!
thermalSubsystemNameCommand

	^  Command getNameCommand.
	
! !

!CommandTest class methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 10/9/2013 15:20'!
thermalSubsystemTelemetryCommand

	^  Command thermalTelemetry.
	
! !

!CommandTest methodsFor: 'execution' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 13:25'!
testSendingNameCommandShouldReturnSubsystemName
	| thermalSubsystem nameCommand response |
	"setup"
	thermalSubsystem := SatelliteTest thermalSubsystem.
	nameCommand := Command getNameCommand.
	
	"exercise"
	response := nameCommand executeOn: thermalSubsystem.
	
	"verify"
	self assert: (response data at: 1) equals: 'THERMAL'! !

!CommandTest methodsFor: 'execution' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 13:25'!
testSendingSetMatrixKeyCommandShouldSetAttributeOnThermalSubsystem
	| thermalSubsystem command response expectedResponse |
	"setup"
	thermalSubsystem := SatelliteTest thermalSubsystem.
	command := Command thermalSetMatrixKey.
	expectedResponse := VoidCommandResponse new.	
	"exercise"
	command addParameterValue: 10.
	response := command executeOn: thermalSubsystem.
	"verify"
	self assert: response equals: expectedResponse.
	self assert: (thermalSubsystem getValueOfAttribute: 'matrix_key') equals: 10! !

TestCase subclass: #ControllerLogTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 23:13'!
testWhenAskingForASequenceNumberNotLoggedTheResultShouldBeFalse
	| log |
	
	log := ControllerLog new.
	
	self deny: (log containsEntryWithSequenceNumber: 1)
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 10:34'!
testWhenLoggingABeaconTheLogEntryShouldContainOnlyTheBeacon
	| log beacon data logEntry |
	
	"setup"
	log := ControllerLog new.
	
	data := OrderedCollection new.
	data add: 'BLAH'.
	beacon := DataCommandResponse newWithSequenceNumber: 16rFFFFF0 andData: data.
	
	"exercise"
	log logResponse: beacon withSequenceNumber: 16rFFFFF0 andBytes: #[1 2 3 4].
	
	"verify"
	self assert: log isEmpty not.
	logEntry := log entries first.
	self assert: (logEntry response) equals: beacon.
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 10:34'!
testWhenLoggingABeaconTheLogEntryShouldContainTheBeaconAndTheCorrespondingByteArray
	| log beacon data logEntry |
	
	"setup"
	log := ControllerLog new.
	
	data := OrderedCollection new.
	data add: 'BLAH'.
	beacon := DataCommandResponse newWithSequenceNumber: 16rFFFFF0 andData: data.
	
	"exercise"
	log logResponse: beacon withSequenceNumber: 16rFFFFF0 andBytes: #[1 2 3 4].
	
	"verify"
	self assert: log isEmpty not.
	logEntry := log entries first.
	self assert: (logEntry response) equals: beacon.
	self assert: (logEntry responseBytes) equals: #[1 2 3 4].
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 10:36'!
testWhenLoggingARequestTheLogEntryShouldContainTheCorrespondingBytes
	| log entry |
	
	log := ControllerLog new.
	
	log logRequest: 'telemetry' withSequenceNumber: 1 andBytes: #[1 2 3 4].
	
	self assert: (log containsEntryWithSequenceNumber: 1).
	entry := log entryWithSequenceNumber: 1.
	self assert: entry requestBytes equals: #[1 2 3 4].! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 10:36'!
testWhenLoggingARequestTheSequenceNumberIsLogged
	| log |
	
	log := ControllerLog new.
	
	log logRequest: 'telemetry' withSequenceNumber: 1 andBytes: #[1 2 3 4].
	
	self assert: (log containsEntryWithSequenceNumber: 1)
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 10:36'!
testWhenLoggingARequestUsingAnExistingSequenceNumberShouldArchiveTheOriginalRequest
	"log using a sequence number and then log again using the same sequence number, to make the log archive the first entry"
	| log newLogEntry logEntryForArchiving archivedLogEntry |
	
	"setup"
	log := ControllerLog new.
	log logRequest: 'messageMovedToTheArchive' withSequenceNumber: 1 andBytes: #[1 2 3 4].
	self assert: (log containsEntryWithSequenceNumber: 1).
	logEntryForArchiving := log entryWithSequenceNumber: 1.
	
	"exercise"
	"this should archive the first entry"
	log logRequest: 'expectedMessage' withSequenceNumber: 1 andBytes: #[1 2 3 4].
	
	"verify"
	newLogEntry := log entryWithSequenceNumber: 1.
	self assert: (newLogEntry request) equals: 'expectedMessage'.
	archivedLogEntry := log archive at: 1.
	self assert: archivedLogEntry equals: logEntryForArchiving.

! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 10:36'!
testWhenLoggingAResponseUsingAnExistingSequenceNumberTheLogEntryShouldContainTheRequestAndTheResponse
	| log logEntry |
	
	"setup"
	log := ControllerLog new.
	log logRequest: 'requestMessage' withSequenceNumber: 1 andBytes: #[1 2 3 4].
		
	"exercise"
	log logResponse: 'responseMessage' withSequenceNumber: 1 andBytes: #[1 2 3 4].
	
	"verify"
	logEntry := log entryWithSequenceNumber: 1.
	self assert: (logEntry request) equals: 'requestMessage'.
	self assert: (logEntry response) equals: 'responseMessage'.
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 10:34'!
testWhenLoggingTwoBeaconsTheLogShouldContainBoth
	| log beacon data logEntry data2 beacon2 |
	
	"setup"
	log := ControllerLog new.
	
	data := OrderedCollection new.
	data add: 'beacon1'.
	beacon := DataCommandResponse newWithSequenceNumber: 16rFFFFF0 andData: data.

	data2 := OrderedCollection new.
	data2 add: 'beacon2'.
	beacon2 := DataCommandResponse newWithSequenceNumber: 16rFFFFF0 andData: data2 .

	"exercise"
	log logResponse: beacon withSequenceNumber: 16rFFFFF0 andBytes: #[1 2 3 4].
	log logResponse: beacon2 andBytes: #[1 2 3 4].
	
	"verify"
	self assert: log isEmpty not.
	logEntry := log entries first.
	self assert: (logEntry response) equals: beacon.
	logEntry := log entries second.
	self assert: (logEntry response) equals: beacon2.
! !

TestCase subclass: #SatelliteControllerTest
	instanceVariableNames: 'clientSocket'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 23:41'!
testDeserealizeBeacon
	| radio satelliteController expectedBeacon serializedBeacon beacon |

	radio := SatelliteControllerRadioStub new.

	satelliteController := SatelliteController newWith: radio.

	serializedBeacon := #[255 255 240 0 0 0 0 0 15 66 64 1 0 0 0 100 0 1 0 2 0 3 0 4 0 5 0 6 0 7 0 8 0 9 0 10 0 11 0 12 0 13 0 10 0 20 0 0 0 10 0 0 0 20 30].
	
	expectedBeacon := SatelliteTest beacon.
	
	beacon := satelliteController decode: serializedBeacon.

	self assert: beacon equals: expectedBeacon.
! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 14:08'!
testDeserealizeShortBeacon
	| radio satelliteController expectedBeacon serializedBeacon beacon |

	radio := SatelliteControllerRadioStub new.

	satelliteController := SatelliteController newWith: radio.

	expectedBeacon := SatelliteTest shortBeacon.
		
	serializedBeacon := #[255 255 243 10 40].
	
	beacon := satelliteController decode: serializedBeacon.

	self assert: beacon equals: expectedBeacon.
! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 12:45'!
testEncodingNameCommandRequestShouldReturnCorrectString

	| satelliteController commandDefinition commandRequest resultingByteArray platformSubsystem |
	
	satelliteController := SatelliteController new.

	commandDefinition :=  CommandDefinition getNameCommand.
	
	commandRequest := CommandRequest for: commandDefinition.
		
	platformSubsystem := SatelliteTest platformSubsystem.
	
	resultingByteArray := satelliteController encode: commandRequest forSubsystem: platformSubsystem withSequenceNumber: (SequenceNumber new).
	
	self assert: resultingByteArray equals:  #[78 129 151 0 0 1 0 0]! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 12:47'!
testEncodingSetMatrixKeyRequestShouldReturnCorrectString

	| satelliteController commandRequest resultingByteArray thermalSubsystem commandDefinition |
	
	satelliteController := SatelliteController new.

	commandDefinition :=  CommandDefinition thermalSetMatrixKey.
	
	commandRequest := CommandRequest for: commandDefinition.
	commandRequest addParameterValue: 1.

	thermalSubsystem := SatelliteTest thermalSubsystem.
	
	resultingByteArray := satelliteController encode: commandRequest forSubsystem: thermalSubsystem withSequenceNumber: (SequenceNumber new).
	
	self assert: resultingByteArray equals:  #[225 246 60 0 0 1 3 32 0 0 0 1]! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 12:48'!
testEncodingTelemetryRequestShouldReturnCorrectString

	| satelliteController commandRequest resultingByteArray thermalSubsystem commandDefinition |

	satelliteController := SatelliteController new.
	
	commandDefinition := CommandDefinition thermalTelemetry.

	commandRequest := CommandRequest for: commandDefinition.

	thermalSubsystem := SatelliteTest thermalSubsystem.
	
	resultingByteArray := satelliteController encode: commandRequest forSubsystem: thermalSubsystem withSequenceNumber: (SequenceNumber new).

	self assert: resultingByteArray equals: #[90 204 175 0 0 1 3 1]! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 11:09'!
testReceivingAPackageFromRadioShouldDecodeMessage

	| radio satelliteController expectedBeacon messages |

	radio := SatelliteControllerRadioStub new.	
	satelliteController := SatelliteController newWith: radio.
	
	expectedBeacon := SatelliteTest beacon.

	"exercise"
	messages := satelliteController newMessages.
	
	self assert: messages size equals: 1.
	self assert: (messages at: 1) data equals: expectedBeacon data.
! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 11:10'!
testReceivingAPackageFromRadioShouldLogEntryWithDecodedMessage

	| radio satelliteController expectedBeacon messages expectedLogEntry log |

	radio := SatelliteControllerRadioStub new.	
	satelliteController := SatelliteController newWith: radio.
	
	expectedBeacon := SatelliteTest beacon.

	"TODO: pass a Clock to the SatelliteController and Log, and assert on the expectedLogEntry instead of its components"
	expectedLogEntry := ControllerLogEntry new.
	expectedLogEntry response: expectedBeacon.
	expectedLogEntry responseBytes: #[255 255 240 0 0 0 0 0 15 66 64 1 0 0 0 100 0 1 0 2 0 3 0 4 0 5 0 6 0 7 0 8 0 9 0 10 0 11 0 12 0 13 0 10 0 20 0 0 0 10 0 0 0 20 30].

	"exercise"
	messages := satelliteController newMessages.

	log := satelliteController log.
	self assert: log entries size equals: 1.
	self assert: (log entries at: 1) response equals: expectedBeacon.
	self assert: (log entries at: 1) responseBytes equals: #[255 255 240 0 0 0 0 0 15 66 64 1 0 0 0 100 0 1 0 2 0 3 0 4 0 5 0 6 0 7 0 8 0 9 0 10 0 11 0 12 0 13 0 10 0 20 0 0 0 10 0 0 0 20 30].
! !

TestCase subclass: #SatelliteTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 23:26'!
beacon

	| satellite |

	satellite := self satelliteWithAllSubsystems.
	
	^ Beacon newFromSubsystems: satellite subsystems.! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
cdhSubsystem
	| cdhSubsystem |

	cdhSubsystem := Subsystem cdh.
	cdhSubsystem setAttribute: 'lastSeenSequenceNumber' withValue: 10.
	cdhSubsystem setAttribute: 'nextBeaconEnableTicks' withValue: 20.
	cdhSubsystem setAttribute: 'antennaDeployStatus' withValue: 30.
	cdhSubsystem setAttribute: 'ticksLow' withValue: 40.
	
	^ cdhSubsystem! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
memorySubsystem
	| memorySub |

	memorySub := Subsystem memory.
	memorySub setAttribute: 'free' withValue: 100.
	
	^ memorySub! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 15:33'!
platformSubsystem
	| platformSub |

	platformSub := Subsystem platform.
	platformSub setAttribute: 'tickCount' withValue: 1000000.
	platformSub setAttribute: 'currentMode' withValue: 1.
	
	^ platformSub! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
powerSubsystem
	| powerSubsystem |

	powerSubsystem := Subsystem power.

	powerSubsystem setAttribute: 'low_voltage_counter' withValue: 1.
	powerSubsystem setAttribute: 'battery_v' withValue: 2.
	powerSubsystem setAttribute: 'array_X_v' withValue: 3.
	powerSubsystem setAttribute: 'array_Xp_mA' withValue: 4.
	powerSubsystem setAttribute: 'array_Xm_mA' withValue: 5.
	powerSubsystem setAttribute: 'array_Y_v' withValue: 6.
	powerSubsystem setAttribute: 'array_Yp_mA' withValue: 7.
	powerSubsystem setAttribute: 'array_Y_mA' withValue: 8.
	powerSubsystem setAttribute: 'array_Z_v' withValue: 9.
	powerSubsystem setAttribute: 'array_Zp_mA' withValue: 10.
	powerSubsystem setAttribute: 'array_Zm_mA' withValue: 11.
	powerSubsystem setAttribute: '_3v3_mA' withValue: 12.
	powerSubsystem setAttribute: '_5v_mA' withValue: 13.
	
	^ powerSubsystem! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/13/2013 18:39'!
satelliteWithAllSubsystems
	| subsystems |

	subsystems := OrderedCollection new.
	
	subsystems add: self platformSubsystem.
	subsystems add: self memorySubsystem.
	subsystems add: self powerSubsystem.
	subsystems add: self thermalSubsystem.
	subsystems add: self cdhSubsystem.

	^ Satellite newWithSubsystems: subsystems.
! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 00:08'!
shortBeacon

	| satellite |

	satellite := self satelliteWithAllSubsystems.
	
	^ ShortBeacon newFromSubsystems: satellite subsystems.! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
thermalSubsystem
	| thermalSub |

	thermalSub := Subsystem thermal.
	thermalSub setAttribute: 'battery_temp' withValue: 10.
	thermalSub setAttribute: 'radio_temp' withValue: 20.
	
	^ thermalSub! !

!SatelliteTest methodsFor: 'receiving' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 12:49'!
testDecodeThermalSubsystemNameCommand

	| satellite bytes commandDefinition decodedCommand satelliteController thermalSubsystem commandRequest |

	"setup"
	satelliteController := SatelliteController new.
	satellite := SatelliteTest satelliteWithAllSubsystems.
	thermalSubsystem := SatelliteTest thermalSubsystem.
	commandDefinition := CommandDefinition getNameCommand.
	commandRequest := CommandRequest for: commandDefinition.
	bytes := satelliteController encode: commandRequest forSubsystem: thermalSubsystem withSequenceNumber: SequenceNumber new.

	"exercise"	
	decodedCommand := satellite receive: bytes.

	"verify"	
	self assert: decodedCommand = commandDefinition.
! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 13:46'!
testEmittingABeaconShouldReturnCollectedTelemetry

	| satellite beacon expectedBeaconData subsystemsOrderedById |

	"setup"
	satellite := SatelliteTest satelliteWithAllSubsystems.

	subsystemsOrderedById := SortedCollection sortBlock: [ :current :new | current id < new id ].
	subsystemsOrderedById addAll: satellite subsystems.

	expectedBeaconData :=  OrderedCollection new.
	
	subsystemsOrderedById do: [ :subsystem | expectedBeaconData addAll: (subsystem telemetry data) ].

	"exercise"	
	beacon := satellite emitBeacon.

	"verify"	
	self assert: beacon data equals: expectedBeaconData.
! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 13:46'!
testEmittingAShortBeaconShouldReturnCollectedShortTelemetry

	| satellite beacon expectedBeaconData subsystemsOrderedById |

	"setup"
	satellite := SatelliteTest satelliteWithAllSubsystems.
	
	subsystemsOrderedById := SortedCollection sortBlock: [ :current :new | current id < new id ].
	subsystemsOrderedById addAll: satellite subsystems.
	
	expectedBeaconData :=  OrderedCollection new.
	
	subsystemsOrderedById do: [ :subsystem | expectedBeaconData addAll: (subsystem shortTelemetry data) ].
	
	"exercise"	
	beacon := satellite emitShortBeacon.

	"verify"	
	self assert: beacon data equals: expectedBeaconData.
! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 23:44'!
testSerializingBeaconShouldSerializeOK
	
	| beacon satellite bytes |

	satellite := SatelliteTest satelliteWithAllSubsystems.
	
	beacon := Beacon newFromSubsystems: satellite subsystems.
	
	bytes := beacon serialize.

	self assert: bytes equals: #[255 255 240 0 0 0 0 0 15 66 64 1 0 0 0 100 0 1 0 2 0 3 0 4 0 5 0 6 0 7 0 8 0 9 0 10 0 11 0 12 0 13 0 10 0 20 0 0 0 10 0 0 0 20 30]! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/18/2013 14:08'!
testSerializingShortBeaconShouldSerializeOK
	
	| beacon satellite bytes |

	satellite := SatelliteTest satelliteWithAllSubsystems.
	
	beacon := ShortBeacon newFromSubsystems: satellite subsystems.
	
	bytes := beacon serialize.

	self assert: bytes equals: #[255 255 243 10 40]! !

TestCase subclass: #SequenceNumberTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 15:50'!
test1AsByteArray
	| sequenceNumber |

	sequenceNumber := SequenceNumber new.

	self assert: sequenceNumber asByteArray equals: #[0 0 1].! !

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 15:50'!
testLastSequenceNumberAsByteArray
	| sequenceNumber lastNumber |
	
	lastNumber := LargePositiveInteger readFrom: 'FFFFF0' base: 16.

	sequenceNumber := SequenceNumber startingFrom: lastNumber.

	self assert: sequenceNumber asByteArray equals: #[255 255 240].! !

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 15:50'!
testNewSequenceNumberStartsIn1
	| sequenceNumber |
	
	sequenceNumber := SequenceNumber new.
	
	self assert: sequenceNumber number equals: 1! !

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 15:50'!
testNextOfLastNumberIs1
	| lastNumber sequenceNumber one |
	
	lastNumber := LargePositiveInteger readFrom: 'FFFFEF' base: 16.
	sequenceNumber := SequenceNumber startingFrom: lastNumber.
	one := sequenceNumber next.
	
	self assert: one equals: 1! !

TestCase subclass: #SubsystemTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
test01WhenCreatingASubsystemTheIdAndNameIsSet

	| subsystem |

	"setup"
	subsystem := Subsystem memory.

	"verify"	
	self assert: subsystem id equals: 1.
	self assert: subsystem name equals: 'MEMORY'.
! !

!SubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
test02WhenCreatingASubsystemItCanAnswerBasicCommands

	| subsystem |

	"setup"
	subsystem := Subsystem thermal.

	"verify"	
	self assert: (subsystem understands: 'name').
	self assert: (subsystem understands: 'telemetry').
	self assert: (subsystem understands: 'short_telemetry').
! !

!SubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
test03WhenCreatingASubsystemItDoesntUnderstandUnknwonCommand

	| subsystem  |

	"setup"
	subsystem := Subsystem memory.

	"verify"	
	self deny: (subsystem understands: 'notACommand').
! !

!SubsystemTest methodsFor: 'subsystem' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/29/2013 19:34'!
test04ThermalShortTelemetryShouldReturnOK

	| subsystem expectedShortTelemetry shortTelemetry data |

	"setup"
	subsystem := SatelliteTest thermalSubsystem.
	data := OrderedCollection new.
	data add: (Association key: 'battery_temp' value: 10).
	expectedShortTelemetry := DataCommandResponse newWithData: data.
	
	"excercise"
	shortTelemetry:=	subsystem shortTelemetry. 

	"verify"	
	self assert: shortTelemetry = expectedShortTelemetry.

! !

!SubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:54'!
test05ThermalTelemetryShouldReturnOK

	| subsystem expectedTelemetry telemetry data |

	"setup"
	subsystem := SatelliteTest thermalSubsystem.
	data := OrderedCollection new.
	data add: (Association key: 'battery_temp' value: 10).
	data add: (Association key: 'radio_temp' value: 20).
	expectedTelemetry := DataCommandResponse newWithData: data.
	
	"excercise"
	telemetry:= subsystem telemetry. 

	"verify"	
	self assert: telemetry = expectedTelemetry.

! !

Object subclass: #SatelliteControllerRadioStub
	instanceVariableNames: 'packages'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SatelliteControllerRadioStub class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/13/2013 19:09'!
newWithPackages: aCollection 
	^ self new initializeWithPackages: aCollection.! !

!SatelliteControllerRadioStub methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/17/2013 23:05'!
beaconPackage
	^ #[255 255 240 0 0 0 0 0 15 66 64 1 0 0 0 100 0 1 0 2 0 3 0 4 0 5 0 6 0 7 0 8 0 9 0 10 0 11 0 12 0 13 0 10 0 20 0 0 0 10 0 0 0 20 30].! !

!SatelliteControllerRadioStub methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/13/2013 19:10'!
initializeWithPackages: aCollection 
	packages := aCollection.! !

!SatelliteControllerRadioStub methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/16/2013 15:20'!
nextPackages
	| result |
	
	result := OrderedCollection new.

	result add: self beaconPackage.

	^ result.! !
